"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const js_beautify_1 = require("js-beautify");
const path_1 = require("path");
const sax_1 = require("sax");
const component_parser_1 = require("./component-parser");
function loader(content, map) {
    const callback = this.async();
    const { appPath, platform } = this.getOptions();
    const moduleRelativePath = (0, path_1.relative)(appPath, this.resourcePath);
    try {
        const output = parseXMLTree(moduleRelativePath, content, platform);
        callback(null, output, map);
    }
    catch (err) {
        callback(err);
    }
}
exports.default = loader;
function parseXMLTree(moduleRelativePath, content, platform) {
    const xmlParser = (0, sax_1.parser)(true, { xmlns: true });
    const componentParser = new component_parser_1.ComponentParser(moduleRelativePath, platform);
    // Register ios and android prefixes as namespaces to avoid "unbound xml namespace" errors
    xmlParser.ns['ios'] = xmlParser.ns['android'] = xmlParser.ns['desktop'] = xmlParser.ns['web'] = 'http://schemas.nativescript.org/tns.xsd';
    xmlParser.onopentag = (node) => {
        componentParser.handleOpenTag(node.local, node.prefix, node.attributes);
    };
    xmlParser.onclosetag = (elementName) => {
        componentParser.handleCloseTag(elementName);
    };
    xmlParser.onerror = (err) => {
        // Allow using ampersand
        if (err.message.includes('Invalid character') && err.message.includes('Char: &')) {
            xmlParser.error = null;
        }
    };
    xmlParser.write(content).close();
    componentParser.finish();
    return (0, js_beautify_1.js)(componentParser.getOutput(), {
        indent_size: 2
    });
}
//# sourceMappingURL=index.js.map